{% if config.BLOGGING_DISQUS_SITENAME %}
    <div class="comment">
        <div id="disqus_thread"></div> <!-- comment app container -->
    </div>
	<!-- Comment BEGIN -->
    <script type="text/javascript">
        var disqus_shortname = '{{ config.BLOGGING_DISQUS_SITENAME }}'; // required: replace example with your forum shortname
        /* * * DON'T EDIT BELOW THIS LINE * * */
        (function() {
            var dsq = document.createElement('script'); dsq.type = 'text/javascript'; dsq.async = true;
            dsq.src = '//' + disqus_shortname + '.disqus.com/embed.js';
            (document.getElementsByTagName('head')[0] || document.getElementsByTagName('body')[0]).appendChild(dsq);
        })();
    </script>
    <noscript>Please enable JavaScript to view the <a href="http://disqus.com/?ref_noscript">comments powered by Disqus.</a></noscript>
     <!-- Comment END -->
{% endif %}